.. Copyright (C) 2012-2020 Bryan A. Jones.

    This file is part of CellBotics.

    CellBotics is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

    CellBotics is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along with CellBotics.  If not, see <http://www.gnu.org/licenses/>.

**********
Cellbotics
**********
This directory contains files to explore interfacing with a CellBot via BLE and for interfacing with sensors available on many smart devices. A Python wrapper for these classes is available in the Skuplt standard library as ``cellbotics``.

.. toctree::
    :maxdepth: 2

    __init__.py
    js/ble.js
    js/simple_sensor.js
    js/permissions_polyfill.js
    js/auto-bind.js
    js/sensor_polyfill/toctree
    test/toctree
